@@ -1,8 +1,8 @@
 package Dist::Zilla::PluginBundle::AVAR;
-BEGIN { $Dist::Zilla::PluginBundle::AVAR::VERSION = '0.34'; }
+our $AUTHORITY = 'cpan:AVAR';
+$Dist::Zilla::PluginBundle::AVAR::VERSION = '0.35';
 use 5.10.0;
 use Moose;
-use Moose::Autobox;
 
 with 'Dist::Zilla::Role::PluginBundle';
 
@@ -316,7 +316,7 @@ E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2010 E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
+Copyright 2023 E<AElig>var ArnfjE<ouml>rE<eth> Bjarmason <avar@cpan.org>
 
 This program is free software, you can redistribute it and/or modify
 it under the same terms as Perl itself.
